==> apache-servicecomb-java-chassis-distribution-2.7.0-src.zip: apache-servicecomb-java-chassis-distribution-2.7.0-src/foundations/foundation-vertx/src/main/java/org/apache/servicecomb/foundation/vertx/executor/VertxContextExecutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.vertx.executor;

import java.util.concurrent.Executor;

import io.vertx.core.Context;
import io.vertx.core.Vertx;

public class VertxContextExecutor implements Executor {
  public static VertxContextExecutor create(Vertx vertx) {
    return new VertxContextExecutor(vertx.getOrCreateContext());
  }

  public static VertxContextExecutor create(Context context) {
    return new VertxContextExecutor(context);
  }

  private Context context;

  private VertxContextExecutor(Context context) {
    this.context = context;
  }

  @Override
  public void execute(Runnable command) {
    if (context == Vertx.currentContext()) {
      command.run();
      return;
    }

    context.runOnContext(v -> command.run());
  }
}

==> apache-servicecomb-java-chassis-distribution-3.3.0-src.zip: apache-servicecomb-java-chassis-distribution-3.3.0-src/foundations/foundation-vertx/src/main/java/org/apache/servicecomb/foundation/vertx/executor/VertxContextExecutor.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.servicecomb.foundation.vertx.executor;

import java.util.concurrent.Executor;

import io.vertx.core.Context;
import io.vertx.core.Vertx;

public class VertxContextExecutor implements Executor {
  public static VertxContextExecutor create(Vertx vertx) {
    return new VertxContextExecutor(vertx.getOrCreateContext());
  }

  public static VertxContextExecutor create(Context context) {
    return new VertxContextExecutor(context);
  }

  private final Context context;

  private VertxContextExecutor(Context context) {
    this.context = context;
  }

  @Override
  public void execute(Runnable command) {
    if (context == Vertx.currentContext()) {
      command.run();
      return;
    }

    context.runOnContext(v -> command.run());
  }
}
